package com.diagbot.facade.data;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.MedNurse;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.service.impl.MedNurseServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.SqlProperties;
import com.diagbot.util.StringUtil;
import com.diagbot.util.TZDBConn;
import com.diagbot.vo.data.ADeleteFlagVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

@Component
public class AMedNurseFacade extends MedNurseServiceImpl {

    private TZDBConn tzDBConn = new TZDBConn();

    @Autowired
    private SqlProperties sqlProperties;

    @Autowired
    @Qualifier("medNurseServiceImpl")
    private MedNurseServiceImpl medNurseServiceImpl;

    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;


    /**
     * 同步前一天
     */
    public void executeMedPacsResult() {

    }

    public void execute(List<MedNurse> medNurseList){
        try {
            List<MedNurse> addE = Lists.newLinkedList();
            List<MedNurse> updateE = Lists.newLinkedList();
            if (medNurseList != null && medNurseList.size() > 0) {
                medNurseList.stream().forEach(s -> {
                    MedNurse medNurse = this.getOne(new QueryWrapper<MedNurse>()
                            .eq("rep_no", s.getRepNo())
                            .eq("behospital_code",s.getBehospitalCode())
                            .eq("hospital_id", s.getHospitalId()), false);
                    if (medNurse != null) {
                        s.setGmtModified(new Date());
                        updateE.add(s);
                    } else {
                        s.setGmtCreate(new Date());
                        addE.add(s);
                    }
                });
            }
            if(addE.size()>0){
                medNurseServiceImpl.saveBatch(addE);
            }
            if(updateE.size()>0){
                this.baseMapper.updateBatchByKey(updateE);
            }
            //aMedAbnormalInfoFacade.saveAbnormalInfo("检查",JSON.toJSONString(medPacsResultList),"","操作成功!");
        }catch (Exception e){
            aMedAbnormalInfoFacade.saveAbnormalInfo("护理信息-保存异常","",JSON.toJSONString(medNurseList),"",e.getMessage());
        }
    }

    public RespDTO deleteFlag(ADeleteFlagVO aDeleteFlagVO){
        try {
            //验证数据是否存在
            if(StringUtil.isEmpty(aDeleteFlagVO.getRepNo())){
                return RespDTO.onError("请输入报告单号!");
            }else if(aDeleteFlagVO.getHospitalId()==null){
                return RespDTO.onError("请输入医院编码!");
            }else {
                UpdateWrapper<MedNurse> updateWrapper=new UpdateWrapper<>();
                updateWrapper.eq("rep_no", aDeleteFlagVO.getRepNo())
                        .eq("hospital_id", aDeleteFlagVO.getHospitalId())
                        .eq("is_deleted", IsDeleteEnum.N)
                        .set("is_deleted",IsDeleteEnum.Y)
                        .set("gmt_modified", DateUtil.now());

                Boolean flag=update(new MedNurse(),updateWrapper);
                //aMedAbnormalInfoFacade.saveAbnormalInfo("检查-删除",JSON.toJSONString(aDeleteFlagVO),JSON.toJSONString(RespDTO.onSuc(flag)),"操作成功!");
                return RespDTO.onSuc(flag);
            }
        }catch (Exception e){
            aMedAbnormalInfoFacade.saveAbnormalInfo("检查信息-删除异常","", JSON.toJSONString(aDeleteFlagVO),"",e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }
}
