package com.diagbot.util;

import com.alibaba.druid.pool.DruidDataSource;
import com.diagbot.entity.*;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.vo.data.AHomeDiagnoseVO;
import com.diagbot.vo.data.AHomeOperationVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;

import java.sql.*;
import java.util.Date;
import java.util.List;
import java.util.ResourceBundle;

public class TZDBConn {
	@Autowired
	private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
	private static final String DRIVER = getValue("jdbc.driverClassName");
	private static final String URL = getValue("jdbc.url");
	private static final String USERNAME = getValue("jdbc.username");
	private static final String PASSWORD = getValue("jdbc.password");

	public static final Long HOSPITAL_ID=Long.valueOf("5");//1:长兴，2：邵逸夫，3：台州市立医院

	private static Connection connection = null;
	private static PreparedStatement sta = null;
	private static ResultSet rs = null;
	private static DruidDataSource druidDataSource;

	/**
	 * 读取属性文件中的信息
	 *
	 * @param key
	 * @return
	 */
	private static String getValue(String key) {
		// 资源包绑定
		ResourceBundle bundle = ResourceBundle.getBundle("jdbc");
		return bundle.getString(key);
	}

	/**
	 * 加载驱动程序
	 */
	static {
		try {
			Class.forName(DRIVER);
		} catch (ClassNotFoundException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @return 连接对象
	 */
	public Connection getConnection() {
		try {
			connection = DriverManager.getConnection(URL,USERNAME,PASSWORD);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return connection;
	}

	/**
	 * @param sql sql语句
	 * @param obj 参数
	 * @return 数据集合
	 */
	public ResultSet Query(String sql,Object...obj){
		connection=getConnection();
		try {
			sta=connection.prepareStatement(sql);
			if(obj!=null){
				for(int i=0;i<obj.length;i++){
					sta.setObject(i+1, obj[i]);
				}
			}
			rs=sta.executeQuery();
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return rs;
	}

	/**
	 * 关闭资源
	 */
	public void close() {
		try {
			if (rs != null) {
				rs.close();
			}
		} catch (SQLException e) {
			e.printStackTrace();
		} finally {
			try {
				if (sta != null) {
					sta.close();
				}
			} catch (SQLException e2) {
				e2.printStackTrace();
			} finally {
				if (connection != null) {
					try {
						connection.close();
					} catch (SQLException e) {
						e.printStackTrace();
					}
				}
			}
		}
	}

	/**
	 * 医生信息
	 * @return
	 */
	public List<BasDoctorInfo> getBasDoctorInfo(String sql) {
		List<BasDoctorInfo> basDoctorInfoList=Lists.newLinkedList();
		TZDBConn dbconn=new TZDBConn();
		try {
			rs =dbconn.Query(sql, null);
			while(rs.next()){
				BasDoctorInfo basDoctorInfo=new BasDoctorInfo();
				basDoctorInfo.setDoctorId(rs.getString("YHRYBH"));//医生ID
				basDoctorInfo.setHospitalId(HOSPITAL_ID);//医院ID
				//basDoctorInfoVO.setDeptId(rs.getString("ZZKSID"));//科室ID
				basDoctorInfo.setName(rs.getString("YHRYMC"));//医生姓名
				basDoctorInfo.setProfessor(rs.getString("YHRYZC"));//职称

				basDoctorInfoList.add(basDoctorInfo);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}

		return basDoctorInfoList;
	}

	/**
	 * 从视图中获取医院科室数据，根据修改时间同步数据
	 * @return
	 */
	public List<BasDeptInfo> getDeptInfo(String sql) {
		List<BasDeptInfo> basDeptInfoList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				BasDeptInfo basDeptInfo=new BasDeptInfo();
				basDeptInfo.setDeptId(rs.getString("ZZKSDM"));//科室编码
				basDeptInfo.setHospitalId(HOSPITAL_ID);//医院ID
				basDeptInfo.setDeptName(rs.getString("ZZKSMC"));//科室名称
				//basDeptInfoVO.setDeptType(rs.getString("ZZKSLB"));//科室类别
				basDeptInfo.setSpell(rs.getString("HZSRM1"));//首字母拼音
				//basDeptInfoVO.setStation(rs.getString("FLKSID"));//区域类别

				basDeptInfoList.add(basDeptInfo);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return basDeptInfoList;
	}

	/**
	 * 病案诊断
	 * @return
	 */
	public List<HomeDiagnoseInfo> getHomeDiagnose(String sql){
		List<HomeDiagnoseInfo> homeDiagnoseVOList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				HomeDiagnoseInfo homeDiagnose=new HomeDiagnoseInfo();
				homeDiagnose.setHomePageId(rs.getString("HOMEPAGEID"));//病案首页ID
				homeDiagnose.setHospitalId(HOSPITAL_ID);//医院ID
				homeDiagnose.setDiagnoseOrderNo(rs.getString("DIAGNOSEORDERNO"));//诊断序号
				homeDiagnose.setDiagnoseName(rs.getString("DIAGNOSENAME"));//诊断名称
				homeDiagnose.setDiagnoseType(rs.getString("DIAGNOSETYPE"));//诊断类别
				homeDiagnose.setDiagnoseTypeShort(rs.getString("DIAGNOSETYPESHORT"));//诊断判别
				homeDiagnose.setBehospitalType(rs.getString("BEHOSPITALTYPE"));//入院情况
				homeDiagnose.setLeaveHospitalType(rs.getString("LEAVEHOSPITALTYPE"));//出院情况
				homeDiagnose.setPathologyDiagnose(rs.getString("PATHOLOGYDIAGNOSE"));//病理号
				homeDiagnose.setIcdCode(rs.getString("ICDCODE"));//诊断编码

				homeDiagnoseVOList.add(homeDiagnose);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}

		return homeDiagnoseVOList;
	}

	/**
	 * 病案手术
	 * @return
	 */
	public List<HomeOperationInfo> getHomeOperation(String sql) {
		List<HomeOperationInfo> homeOperationVOList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				HomeOperationInfo homeOperationVO=new HomeOperationInfo();
				homeOperationVO.setHomePageId(rs.getString("HOMEPAGEID"));//病案首页ID
				homeOperationVO.setHospitalId(HOSPITAL_ID);//医院ID
				homeOperationVO.setOperationOrderNo(rs.getString("OPERATIONORDERNO"));//手术序号
				homeOperationVO.setOperationDate(rs.getDate("OPERATIONDATE"));//手术日期
				homeOperationVO.setOperationCode(rs.getString("OPERATIONCODE"));//手术编码
				homeOperationVO.setOperationDoctorId(rs.getString("OPERATIONDOCTORID"));//手术医生
				homeOperationVO.setFirstAssistantId(rs.getString("FIRSTASSISTANTID"));//一助医生
				homeOperationVO.setSecondAssistantId(rs.getString("SECONDASSISTANTID"));//二助医生
				homeOperationVO.setCutLevel(rs.getString("CUTLEVEL"));//切口等级
				homeOperationVO.setHealingLevel(rs.getString("HEALINGLEVEL"));//愈合等级
				homeOperationVO.setOperationName(rs.getString("OPERATIONNAME"));//手术名称
				homeOperationVO.setOperationLevel(rs.getString("OPERATIONLEVEL"));//手术级别
				homeOperationVO.setAnaesthesiaName(rs.getString("ANAESTHESIANAME"));//麻醉方式
				homeOperationVO.setShamOperationName(rs.getString("SHAMOPERATIONNAME"));//拟手术名称

				homeOperationVOList.add(homeOperationVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		List<HomeOperationInfo> homeOperationList=BeanUtil.listCopyTo(homeOperationVOList, HomeOperationInfo.class);
		return homeOperationList;
	}

	/**
	 * 从视图获取病案首页信息
	 * 获取近几个月的数据
	 */
	public List<HomePage> getHomePage(String sql) {
		List<HomePage> homePageList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				HomePage homePageVO=new HomePage();
				homePageVO.setHomePageId(rs.getString("HOMEPAGEID"));//病案首页ID
				homePageVO.setHospitalId(HOSPITAL_ID);//医院ID
				homePageVO.setBehospitalCode(rs.getString("BEHOSPITALCODE"));//病人住院序号
				homePageVO.setHospitalCode(rs.getString("HOSPITALCODE"));//组织机构id
				homePageVO.setHospitalName(rs.getString("HOSPITALNAME"));//医疗机构名称
				homePageVO.setOrgCode(rs.getString("ORGCODE"));//医疗机构代码
				homePageVO.setPayType(rs.getString("PAYTYPE"));//医疗付费方式
				homePageVO.setHealthCard(rs.getString("HEALTHCARD"));//健康卡号
				homePageVO.setBehospitalNum(rs.getString("BEHOSPITALNUM"));//住院次数
				homePageVO.setFileCode(rs.getString("FILECODE"));//病案号
				homePageVO.setName(rs.getString("NAME"));//姓名
				homePageVO.setSex(rs.getString("SEX"));//性别
				homePageVO.setBirthday(rs.getDate("BIRTHDAY"));//出生日期
				homePageVO.setAge(rs.getString("AGE"));//病人年龄
				homePageVO.setAgeUnit(rs.getString("AGEUNIT"));//年龄单位
				homePageVO.setNationality(rs.getString("NATIONALITY"));//国籍
				homePageVO.setNewbornMonth(rs.getString("NEWBORNMONTH"));//新生儿出生月数
				homePageVO.setNewbornDay(rs.getString("NEWBORNDAY"));//新生儿出生天数
				homePageVO.setNewbornWeight(rs.getString("NEWBORNWEIGHT"));//新生儿出生体重
				homePageVO.setNewbornBehospitalWeight(rs.getString("NEWBORNBEHOSPITALWEIGHT"));//新生儿入院体重
				homePageVO.setBornAddress(rs.getString("BORNADDRESS"));//出生地
				homePageVO.setBornPlace(rs.getString("BORNPLACE"));//籍贯
				homePageVO.setNation(rs.getString("NATION"));//民族
				homePageVO.setIdentityCardNo(rs.getString("IDENTITYCARDNO"));//身份证号
				homePageVO.setJobType(rs.getString("JOBTYPE"));//职业
				homePageVO.setMarriage(rs.getString("MARRIAGE"));//婚姻
				homePageVO.setCurAddress(rs.getString("CURADDRESS"));//现住址
				homePageVO.setCurPhone(rs.getString("CURPHONE"));//现住址电话
				homePageVO.setCurPostCode(rs.getString("CURPOSTCODE"));//现住址邮编
				homePageVO.setResidenceAddress(rs.getString("RESIDENCEADDRESS"));//户口地址
				homePageVO.setResidencePostCode(rs.getString("RESIDENCEPOSTCODE"));//户口地址邮编
				homePageVO.setWorkAddress(rs.getString("WORKADDRESS"));//工作单位
				homePageVO.setWorkPhone(rs.getString("WORKPHONE"));//工作单位电话
				homePageVO.setWorkPostCode(rs.getString("WORKPOSTCODE"));//工作单位邮编
				homePageVO.setContactName(rs.getString("CONTACTNAME"));//联系人姓名
				homePageVO.setContactRelation(rs.getString("CONTACTRELATION"));//联系人关系
				homePageVO.setContactAddress(rs.getString("CONTACTADDRESS"));//联系人地址
				homePageVO.setContactPhone(rs.getString("CONTACTPHONE"));//联系人电话
				homePageVO.setBehospitalWay(rs.getString("BEHOSPITALWAY"));//入院途径
				homePageVO.setBehospitalDate(rs.getDate("BEHOSPITALDATE"));//入院时间
				homePageVO.setBehospitalDept(rs.getString("BEHOSPITALDEPT"));//入院科室
				homePageVO.setBehospitalWard(rs.getString("BEHOSPITALWARD"));//入院病房
				homePageVO.setBehospitalBedId(rs.getString("BEHOSPITALBEDID"));//入院床位序号
				homePageVO.setBehospitalBedCode(rs.getString("BEHOSPITALBEDCODE"));//入院床位号码
				homePageVO.setChangeDept(rs.getString("CHANGEDEPT"));//转科科别
				homePageVO.setLeaveHospitalDate(rs.getDate("LEAVEHOSPITALDATE"));//出院时间
				homePageVO.setLeaveHospitalDept(rs.getString("LEAVEHOSPITALDEPT"));//出院科别
				homePageVO.setLeaveHospitalWard(rs.getString("LEAVEHOSPITALWARD"));//出院病房
				homePageVO.setLeaveHospitalBedId(rs.getString("LEAVEHOSPITALBEDID"));//出院床位序号
				homePageVO.setLeaveHospitalBedCode(rs.getString("LEAVEHOSPITALBEDCODE"));//出院床位号码
				homePageVO.setBehospitalDayNum(rs.getString("BEHOSPITALDAYNUM"));//实际住院天数
				homePageVO.setOutpatientEmrDiagnose(rs.getString("OUTPATIENTEMRDIAGNOSE"));//门急诊诊断
				homePageVO.setOutpatientEmrDiagnoseCode(rs.getString("OUTPATIENTEMRDIAGNOSECODE"));//门急诊诊断编码
				homePageVO.setPoisonFactor(rs.getString("POISONFACTOR"));//损伤中毒因素
				homePageVO.setPoisonFactorCode(rs.getString("POISONFACTORCODE"));//损伤中毒因素编码
				homePageVO.setPathologyDiagnose(rs.getString("PATHOLOGYDIAGNOSE"));//病理诊断
				homePageVO.setPathologyDiagnoseCode(rs.getString("PATHOLOGYDIAGNOSECODE"));//病理诊断编码
				homePageVO.setPathologyDiagnoseId(rs.getString("PATHOLOGYDIAGNOSEID"));//病理诊断编号
				homePageVO.setIsMedAllergy(rs.getString("ISMEDALLERGY"));//药物过敏
				homePageVO.setMedAllergyName(rs.getString("MEDALLERGYNAME"));//过敏药物
				homePageVO.setAutopsy(rs.getString("AUTOPSY"));//死亡患者尸检
				homePageVO.setBloodType(rs.getString("BLOODTYPE"));//血型
				homePageVO.setRh(rs.getString("RH"));//Rh
				homePageVO.setDeptDirector(rs.getString("DEPTDIRECTOR"));//科主任
				homePageVO.setDirectorDoctor(rs.getString("DIRECTORDOCTOR"));//主任医师
				homePageVO.setAttendingDoctor(rs.getString("ATTENDINGDOCTOR"));//主治医师
				homePageVO.setBehospitalDoctor(rs.getString("BEHOSPITALDOCTOR"));//住院医师
				homePageVO.setResponseNurse(rs.getString("RESPONSENURSE"));//责任护士
				homePageVO.setStudyDoctor(rs.getString("STUDYDOCTOR"));//进修医师
				homePageVO.setPracticeDoctor(rs.getString("PRACTICEDOCTOR"));//实习医师
				homePageVO.setEncodeMan(rs.getString("ENCODEMAN"));//编码员
				homePageVO.setHomePageQuality(rs.getString("HOMEPAGEQUALITY"));//病案质量
				homePageVO.setQcDoctor(rs.getString("QCDOCTOR"));//质控医师
				homePageVO.setQcNurse(rs.getString("QCNURSE"));//质控护士
				if(!"".equals(rs.getString("QCDATE"))){
					homePageVO.setQcDate(DateUtil.parseDate(rs.getString("QCDATE"),DateUtil.DATE_TIME_FORMAT));//质控日期
				}
				homePageVO.setLeaveHospitalType(rs.getString("LEAVEHOSPITALTYPE"));//离院方式
				homePageVO.setAcceptOrgCode(rs.getString("ACCEPTORGCODE"));//接收机构名称
				homePageVO.setAgainBehospitalPlan(rs.getString("AGAINBEHOSPITALPLAN"));//31天内再住院计划
				homePageVO.setAgainBehospitalGoal(rs.getString("AGAINBEHOSPITALGOAL"));//再住院目的
				homePageVO.setTbiBeforeDay(rs.getString("TBIBEFOREDAY"));//颅脑损伤患者昏迷前天数
				homePageVO.setTbiBeforeHour(rs.getString("TBIBEFOREHOUR"));//颅脑损伤患者昏迷前小时
				homePageVO.setTbiBeforeMinute(rs.getString("TBIBEFOREMINUTE"));//颅脑损伤患者昏迷前分钟
				homePageVO.setTbiAfterDay(rs.getString("TBIAFTERDAY"));//颅脑损伤患者昏迷后天数
				homePageVO.setTbiAfterHour(rs.getString("TBIAFTERHOUR"));//颅脑损伤患者昏迷后小时
				homePageVO.setTbiAfterMinute(rs.getString("TBIAFTERMINUTE"));//颅脑损伤患者昏迷后分钟
				homePageVO.setTotalFee(rs.getString("TOTALFEE"));//总费用
				homePageVO.setOwnFee(rs.getString("OWNFEE"));//自付金额
				homePageVO.setGeneralFee(rs.getString("GENERALFEE"));//一般医疗服务费
				homePageVO.setServiceFee(rs.getString("SERVICEFEE"));//一般治疗服务费
				homePageVO.setNurseFee(rs.getString("NURSEFEE"));//护理费
				homePageVO.setOtherFee(rs.getString("OTHERFEE"));//其他费用
				homePageVO.setPathologyFee(rs.getString("PATHOLOGYFEE"));//病理诊断费
				homePageVO.setLabFee(rs.getString("LABFEE"));//实验室诊断费
				homePageVO.setPacsFee(rs.getString("PACSFEE"));//影像学诊断费
				homePageVO.setClinicDiagnoseFee(rs.getString("CLINICDIAGNOSEFEE"));//临床诊断项目费
				homePageVO.setNotOperationFee(rs.getString("NOTOPERATIONFEE"));//非手术治疗项目费
				homePageVO.setClinicPhysicFee(rs.getString("CLINICPHYSICFEE"));//临床物理治疗费
				homePageVO.setOperationTreatFee(rs.getString("OPERATIONTREATFEE"));//手术治疗费
				homePageVO.setAnaesthesiaFee(rs.getString("ANAESTHESIAFEE"));//麻醉费
				homePageVO.setOperationFee(rs.getString("OPERATIONFEE"));//手术费
				homePageVO.setHealthTypeFee(rs.getString("HEALTHTYPEFEE"));//康复类
				homePageVO.setChnTreatFee(rs.getString("CHNTREATFEE"));//中医治疗费
				homePageVO.setWesternMedFee(rs.getString("WESTERNMEDFEE"));//西药费
				homePageVO.setAntibiosisFee(rs.getString("ANTIBIOSISFEE"));//抗菌药物费用
				homePageVO.setChnMedFee(rs.getString("CHNMEDFEE"));//中成药费
				homePageVO.setChnHerbFee(rs.getString("CHNHERBFEE"));//中草药费
				homePageVO.setBloodFee(rs.getString("BLOODFEE"));//血费
				homePageVO.setAlbumenFee(rs.getString("ALBUMENFEE"));//白蛋白类制品费
				homePageVO.setGlobulinFee(rs.getString("GLOBULINFEE"));//球蛋白类制品费
				homePageVO.setBloodFactorFee(rs.getString("BLOODFACTORFEE"));//凝血因子类制品费
				homePageVO.setCellFactorFee(rs.getString("CELLFACTORFEE"));//细胞因子类制品费
				homePageVO.setCheckMaterialFee(rs.getString("CHECKMATERIALFEE"));//检查用一次性医用材料费
				homePageVO.setTreatMaterialFee(rs.getString("TREATMATERIALFEE"));//治疗用一次性医用材料费
				homePageVO.setOperationMaterialFee(rs.getString("OPERATIONMATERIALFEE"));//手术用一次性医用材料费
				homePageVO.setOtherTypeFee(rs.getString("OTHERTYPEFEE"));//其他类其他费
				homePageVO.setSingleDiagManage(rs.getString("SINGLEDIAGMANAGE"));//单病种管理
				homePageVO.setClinicPathwayManage(rs.getString("CLINICPATHWAYMANAGE"));//临床路径管理
				homePageVO.setIsOutpatientBehospital(rs.getString("ISOUTPATIENTBEHOSPITAL"));//门诊与住院
				homePageVO.setIsLeaveBehospital(rs.getString("ISLEAVEBEHOSPITAL"));//入院与出院
				homePageVO.setIsOperationBeforeAfter(rs.getString("ISOPERATIONBEFOREAFTER"));//术前与术后
				homePageVO.setIsClinicPathology(rs.getString("ISCLINICPATHOLOGY"));//临床与病理
				homePageVO.setIsRadiatePathology(rs.getString("ISRADIATEPATHOLOGY"));//放射与病理
				homePageVO.setRescueNum(rs.getString("RESCUENUM"));//病人抢救次数
				homePageVO.setRescueSuccessNum(rs.getString("RESCUESUCCESSNUM"));//病人抢救成功次数
				homePageVO.setIsAutoLeavehospital(rs.getString("ISAUTOLEAVEHOSPITAL"));//是否为自动出院
				homePageVO.setReturnToType(rs.getString("RETURNTOTYPE"));//转归情况HomePage homePageVO=new HomePage();
				homePageList.add(homePageVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return homePageList;
	}

	/**
	 * 获取病历信息
	 * @return
	 */
	public List<BehospitalInfo> getBehospitalInfo(String sql) {
		List<BehospitalInfo> behospitalInfoList=Lists.newLinkedList();
		int i = 1;
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				i++;
				BehospitalInfo behospitalInfo=new BehospitalInfo();
				behospitalInfo.setBehospitalCode(rs.getString("BEHOSPITALCODE"));//病人住院ID
				behospitalInfo.setHospitalId(HOSPITAL_ID);//医院ID
				behospitalInfo.setName(rs.getString("NAME"));//姓名
				behospitalInfo.setSex(rs.getString("SEX"));//性别
				behospitalInfo.setBirthday(DateUtil.parseDate(rs.getString("BIRTHDAY")));//出生日期
				behospitalInfo.setFileCode(rs.getString("FILECODE"));//档案号
				behospitalInfo.setWardCode(rs.getString("WARDCODE"));//病区编码
				behospitalInfo.setWardName(rs.getString("WARDNAME"));//病区名称
				behospitalInfo.setBehDeptId(rs.getString("BEHDEPTID"));//住院科室ID
				behospitalInfo.setBehDeptName(rs.getString("BEHDEPTNAME"));//住院科室名称
				behospitalInfo.setBedCode(rs.getString("BEDCODE"));//床位号
				behospitalInfo.setBedName(rs.getString("BEDNAME"));
				behospitalInfo.setInsuranceName(rs.getString("INSURANCENAME"));//医保类别
				behospitalInfo.setJobType(rs.getString("JOBTYPE"));//职业
				Date behospitaldate = DateUtil.parseDateTime(rs.getString("BEHOSPITALDATE"));//入院时间
				Date leavehospitaldate = DateUtil.parseDateTime(rs.getString("LEAVEHOSPITALDATE"));//出院时间
				behospitalInfo.setBehospitalDate(behospitaldate);
				behospitalInfo.setLeaveHospitalDate(leavehospitaldate);
				behospitalInfo.setDiagnoseIcd(rs.getString("DIAGNOSEICD"));//疾病ICD编码
				behospitalInfo.setDiagnose(rs.getString("DIAGNOSE"));//疾病名称
				behospitalInfo.setBehDoctorId(rs.getString("BEHDOCTORID"));
				behospitalInfo.setBehDoctorName(rs.getString("BEHDOCTORNAME"));
				behospitalInfo.setDirectorDoctorId(rs.getString("DIRECTORDOCTORID"));
				behospitalInfo.setDirectorDoctorName(rs.getString("DIRECTORDOCTORNAME"));
				behospitalInfo.setDoctorId(rs.getString("DOCTORID"));//医生ID
				behospitalInfo.setDoctorName(rs.getString("DOCTORNAME"));//医生姓名
				behospitalInfo.setIsBaby(rs.getString("YINGERBZ"));//婴儿标志
				behospitalInfo.setIsPlacefile(rs.getString("ISPLACEFILE"));
				behospitalInfo.setIsDaytime(rs.getString("ISDAYTIME"));//日间病例标志
				behospitalInfo.setPlacefileDate(DateUtil.parseDateTime(rs.getString("PLACEFILEDATE")));
				behospitalInfo.setIsCancelBehospital(rs.getString("QUXIAORYBZ"));
				behospitalInfoList.add(behospitalInfo);
			}
			aMedAbnormalInfoFacade.saveAbnormalInfo("获取病历信息-语句查询对应TZDBConn","查询出的总数"+i, sql,"","");
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}

		return behospitalInfoList;
	}
	/**
	 * 从试图中获取日间病例标识
	 * ISDAYTIME
	 */
	public String getIsDaytime(String sql){
		String isDaytime = "";
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			aMedAbnormalInfoFacade.saveAbnormalInfo(rs+"mrRecord", "+++++", rs.getString("ISDAYTIME"), "", "!");
			isDaytime=rs.getString("ISDAYTIME");
			/*System.out.println(rs);
			if (rs.next()) {
				aMedAbnormalInfoFacade.saveAbnormalInfo(rs+"_____________", "____________", rs.getString("ISDAYTIME"), "", "!");
				System.out.println(rs);
			}*/

		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return isDaytime;
	}
	/**
	 * 从视图中获取医嘱信息
	 * @return
	 */
	public List<DoctorAdvice> getDoctorAdvice(String sql){
		List<DoctorAdvice> doctorAdviceList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				DoctorAdvice doctorAdviceVO=new DoctorAdvice();
				doctorAdviceVO.setDoctorAdviceId(rs.getString("DOCTORADVICEID"));//病人医嘱ID
				doctorAdviceVO.setHospitalId(HOSPITAL_ID);//医院ID
				doctorAdviceVO.setBehospitalCode(rs.getString("BEHOSPITALCODE"));//病人ID
				doctorAdviceVO.setOrderDoctorName(rs.getString("ORDERDOCTORNAME"));//医生开单判别
				doctorAdviceVO.setFrequency(rs.getString("FREQUENCY"));//医嘱频率判别
				doctorAdviceVO.setParentTypeId(rs.getString("PARENTTYPEID"));//父类医嘱ID
				doctorAdviceVO.setDoctorAdviceType(rs.getString("DOCTORADVICETYPE"));//医嘱类型判别
				doctorAdviceVO.setUsageNum(String.valueOf(rs.getDouble("USAGENUM")));//一次使用数量
				doctorAdviceVO.setUsageUnit(rs.getString("USAGEUNIT"));//一次用量单位
				doctorAdviceVO.setDose(String.valueOf(rs.getDouble("DOSE")));//医嘱单次剂量
				doctorAdviceVO.setDoseUnit(rs.getString("DOSEUNIT"));//单次剂量单位
				doctorAdviceVO.setMedModeType(rs.getString("MEDMODETYPE"));//给药方式
				doctorAdviceVO.setMedicineType(String.valueOf(rs.getInt("MEDICINETYPE")));//药品类型
				doctorAdviceVO.setDaFrequency(rs.getString("DAFREQUENCY"));//医嘱频率
				doctorAdviceVO.setDaDealType(rs.getString("DADEALTYPE"));//医嘱处理类型
				if (StringUtil.isNotEmpty(rs.getString("DASTARTDATE"))){
					doctorAdviceVO.setDaStartDate(DateUtil.parseDate(rs.getString("DASTARTDATE"),DateUtil.DATE_TIME_FORMAT));//医嘱开始时间
				}
				doctorAdviceVO.setDaItemName(rs.getString("DAITEMNAME"));//医嘱项目名称
				doctorAdviceVO.setDaStatus(rs.getString("DASTATUS"));//医嘱状态判别
				if (StringUtil.isNotEmpty(rs.getString("DASTOPDATE"))){
					doctorAdviceVO.setDaStopDate(DateUtil.parseDate(rs.getString("DASTOPDATE"),DateUtil.DATE_TIME_FORMAT));//医嘱结束时间
				}
				doctorAdviceVO.setDaGroupNo(rs.getString("DAGROUPNO"));//医嘱同组序号
				doctorAdviceVO.setDaPrescriptionType(rs.getString("DAPRESCRIPTIONTYPE"));//医嘱处方类型
				doctorAdviceVO.setDaMedType(rs.getString("DAMEDTYPE"));//医嘱领药类型
				doctorAdviceVO.setDoctorNotice(rs.getString("DOCTORNOTICE"));//医生嘱托
				doctorAdviceVO.setDoctorId(rs.getString("DOCTORID"));//开单医生ID
				doctorAdviceVO.setDoctorName(rs.getString("DOCTORNAME"));//开单医生姓名
				if(rs.getString("DASTATUS").equals("CA") || rs.getString("DASTATUS").equals("HD")){
					doctorAdviceVO.setIsDeleted("Y");
				}
				doctorAdviceList.add(doctorAdviceVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return doctorAdviceList;
	}

	/**
	 * 从视图中获取病历记录
	 * @return
	 */
	public List<MedicalRecord> getMedicalRecord(String sql){
		List<MedicalRecord> medicalRecordList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedicalRecord medicalRecord=new MedicalRecord();
				medicalRecord.setRecId(rs.getString("RECID"));
				medicalRecord.setHospitalId(HOSPITAL_ID);//医院ID
				medicalRecord.setBehospitalCode(rs.getString("BEHOSPITALCODE"));//病人住院ID
				medicalRecord.setOrgCode(rs.getString("ORGCODE"));//组织机构代码
				medicalRecord.setRecTypeId(rs.getString("RECTYPEID"));//对应his模板ID
				medicalRecord.setRecDate(rs.getString("RECDATE")!=null?DateUtil.parseDateTime(rs.getString("RECDATE")):null);//病历日期
				medicalRecord.setRecTitle(rs.getString("RECTITLE"));//病历标题
				//medicalRecord.setModeId(Long.valueOf(rs.getString("BLLBID")));//对应his类别ID
				medicalRecordList.add(medicalRecord);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return medicalRecordList;
	}

	/**
	 * 从视图中获取文书内容
	 * @return
	 */
	public List<MedicalRecordContent> getMedicalRecordContent(String sql){
		List<MedicalRecordContent> mrContentList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedicalRecordContent mrContent=new MedicalRecordContent();
				mrContent.setHospitalId(HOSPITAL_ID);
				mrContent.setRecId(rs.getString("RECID"));
				//mrContent.setHtmlText(rs.getString("HTMLSJ"));
				mrContent.setXmlText(rs.getString("CONTENTS"));
				mrContentList.add(mrContent);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return mrContentList;
	}

	/**
	 * 从视图中获取文书类型
	 * @return
	 */
	public List<MedRecordType> getMedicalRecordType(String sql){
		List<MedRecordType> mrTypeList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedRecordType mrType=new MedRecordType();
				mrType.setTypeId(rs.getString("TYPEID"));
				mrType.setHospitalId(HOSPITAL_ID);
				mrType.setTypeName(rs.getString("MOBANLXMC"));
				mrType.setParentTypeId(rs.getString("FULEIMBLX"));
				mrType.setObjName(rs.getString("OBJNAME"));
				mrType.setSpell(rs.getString("SPELL"));
				mrTypeList.add(mrType);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}

		return mrTypeList;
	}

	/**
	 * 从视图中获取化验
	 * @return
	 */
	public List<MedLisResult> getLisResult(String sql){
		List<MedLisResult> medLisResultList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedLisResult medLisResult=new MedLisResult();
				medLisResult.setRepNo(rs.getString("REPTNO"));
				medLisResult.setHospitalId(HOSPITAL_ID);
				medLisResult.setBehospitalCode(rs.getString("BEHOSPITALCODE"));
				medLisResult.setItemCode(rs.getString("ITEMCODE"));
				medLisResult.setItemName(rs.getString("ITEMNAME"));
				medLisResult.setResult(rs.getString("RESULT"));
				medLisResult.setReference(rs.getString("CANKAOFW"));
//				medLisResult.setReferenceMin(rs.getString("REFERENCEMIN"));
//				medLisResult.setReferenceMax(rs.getString("REFERENCEMAX"));
				medLisResult.setUnit(rs.getString("UNIT"));
				medLisResult.setAbnormal(rs.getString("ABNORMAL"));
				medLisResult.setColor(rs.getString("COLOR"));
				medLisResultList.add(medLisResult);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}

		return medLisResultList;
	}


	/**
	 * 从视图中获取化验
	 * @return
	 */
	public List<MedPacsResult> getPacsResult(String sql){
		List<MedPacsResult> medPacsResultList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedPacsResult medPacsResult=new MedPacsResult();
				medPacsResult.setRepNo(rs.getString("REPTNO"));
				medPacsResult.setHospitalId(HOSPITAL_ID);
 				medPacsResult.setBehospitalCode(rs.getString("BEHOSPITALCODE"));
				medPacsResult.setReptName(rs.getString("REPTNAME"));
				medPacsResult.setPart(rs.getString("PART"));
				medPacsResult.setClinicSight(rs.getString("CLINICSIGHT"));
				medPacsResult.setReptDiag(rs.getString("REPTDIAG"));
				medPacsResult.setRemark(rs.getString("REMARK"));
				medPacsResult.setClinicDiag(rs.getString("CLINICDIAG"));
				medPacsResult.setApplyDoctor(rs.getString("APPLYDOCTOR"));
				medPacsResult.setCheckerDoctor(rs.getString("CHECKERDOCTOR"));
				medPacsResult.setReportDoctor(rs.getString("REPORTDOCTOR"));
				medPacsResult.setDeptName(rs.getString("DEPTNAME"));
				medPacsResultList.add(medPacsResult);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return medPacsResultList;
	}

	/**
	 * 从视图获取危急值
	 * @param sql
	 * @return
	 */
	public List<MedCrisisInfo> getMedCrisisInfo(String sql){
		List<MedCrisisInfo> medCheckInfoList = Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedCrisisInfo medCrisisInfo = new MedCrisisInfo();
				medCrisisInfo.setRecId(rs.getString("RECID"));
				medCrisisInfo.setHospitalId(HOSPITAL_ID);
				medCrisisInfo.setBehospitalCode(rs.getString("BEHOSPITALCODE"));
				medCrisisInfo.setRecType(rs.getString("RECTYPE"));
				medCrisisInfo.setCrisisId(rs.getString("CRISISID"));
				medCrisisInfo.setCrisisName(rs.getString("CRISISNAME"));
				medCrisisInfo.setDeptId(rs.getString("DEPTID"));
				medCrisisInfo.setDeptName(rs.getString("DEPTNAME"));
				medCrisisInfo.setDoctorId(rs.getString("DOCTORID"));
				medCrisisInfo.setDoctorName(rs.getString("DOCTORNAME"));
				medCrisisInfo.setCrisisValue(rs.getString("CRISISVALUE"));
				medCrisisInfo.setCrisisDesc(rs.getString("CRISISDESC"));
				medCrisisInfo.setCrisisStatus(rs.getString("CRISISSTATUS"));
				medCrisisInfo.setCrisisTopValue(rs.getString("CRISISTOPVALUE"));
				medCrisisInfo.setCrisisLowerValue(rs.getString("CRISISLOWERVALUE"));
				medCrisisInfo.setSendDate(rs.getDate("SENDDATE"));
				medCrisisInfo.setRepDate(rs.getDate("REPDATE"));
				medCheckInfoList.add(medCrisisInfo);
			}
		}catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return medCheckInfoList;
	}

	public List<MedPacsInfo> getPacsInfo(String sql){
		List<MedPacsInfo>  medPacsInfoList= Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedPacsInfo medPacsInfo=new MedPacsInfo();
				medPacsInfo.setRepNo(rs.getString("REPNO"));//报告单号
				medPacsInfo.setHospitalId(HOSPITAL_ID);//医院ID
				medPacsInfo.setBehospitalCode(rs.getString("BEHOSPITALCODE"));//住院病人ID
				medPacsInfo.setRepType(rs.getString("REPTYPE"));//报告类型代码
				medPacsInfo.setRepName(rs.getString("REPNAME"));//检查类型名称
				medPacsInfo.setRepTypeName(rs.getString("REPTYPENAME"));//检查类型名称
				medPacsInfo.setPart(rs.getString("PART"));//检查部位
				medPacsInfo.setRepDate(rs.getString("REPDATE"));//发布时间
				medPacsInfo.setCheckDate(rs.getString("CHECKDATE"));//报告检查时间
				medPacsInfo.setApplyDoctor(rs.getString("APPLYDOCTOR"));//申请医生
				medPacsInfo.setDeptId(rs.getString("DEPTID"));//开单科室代码
				medPacsInfo.setDeptName(rs.getString("DEPTNAME"));//开单科室名称
				medPacsInfo.setRegisterFlag(rs.getString("REGISTERFLAG"));;//报告单状态
				medPacsInfo.setReportDoctor(rs.getString("REPORTDOCTOR"));
				medPacsInfo.setChecker(rs.getString("CHECKER"));
				medPacsInfo.setYjpdz(rs.getString("YJPDZ"));
				medPacsInfoList.add(medPacsInfo);
			}
		}catch (Exception e){
			e.printStackTrace();
		}finally {
			close();
		}
		return medPacsInfoList;
	}

	public List<MedLisInfo> getLisInfo(String sql){
		List<MedLisInfo>  medLisInfoList= Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				MedLisInfo medLisInfo=new MedLisInfo();
				medLisInfo.setRepNo(rs.getString("REPNO"));//报告单号
				medLisInfo.setHospitalId(HOSPITAL_ID);//医院ID
				medLisInfo.setBehospitalCode(rs.getString("BEHOSPITALCODE"));//住院病人ID
				medLisInfo.setRepType(rs.getString("REPTYPE"));//报告类型代码
				medLisInfo.setRepName(rs.getString("REPNAME"));//检查类型名称
				medLisInfo.setRepTypeName(rs.getString("REPTYPENAME"));//检查类型名称
				medLisInfo.setSlideType(rs.getString("SLIDETYPE"));//标本名称
				medLisInfo.setRepDate(rs.getString("REPDATE"));//发布时间
				medLisInfo.setCheckDate(rs.getString("CHECKDATE"));//报告检查时间
				medLisInfo.setApplyDoctor(rs.getString("APPLYDOCTOR"));//申请医生
				medLisInfo.setDeptId(rs.getString("DEPTID"));//开单科室代码
				medLisInfo.setDeptName(rs.getString("DEPTNAME"));//开单科室名称
				medLisInfo.setRegisterFlag(rs.getString("REGISTERFLAG"));;//报告单状态
				medLisInfoList.add(medLisInfo);
			}
		}catch (Exception e){
			e.printStackTrace();
		}finally {
			close();
		}
		return medLisInfoList;
	}

	public String getRecordXml(String sql){
		String xml = "";
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				xml = rs.getString("CONTENTS");
			}
		}catch (Exception e){
			e.printStackTrace();
		}finally {
			close();
		}
		return xml;
	}

	public String getDoctorName(String doctorId){
		String doctorName = "";
		String sql = "SELECT * FROM AI_V_SENDDOCTORINFOS t WHERE t.DOCTORID='" + doctorId + "' AND ROWNUM=1";
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				doctorName = rs.getString("NAME");
			}
		}catch (Exception e){
			e.printStackTrace();
		}finally {
			close();
		}
		return doctorName;
	}

	public String getDeptName(String deptId){
		String deptName = "";
		String sql = "SELECT * FROM AI_V_SENDDEPTINFOS t WHERE t.DEPTID='" + deptId + "'AND ROWNUM=1";
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				deptName = rs.getString("DEPTNAME");
			}
		}catch (Exception e){
			e.printStackTrace();
		}finally {
			close();
		}
		return deptName;
	}

	public List<AHomeOperationVO> getHomePageOperation(String sql) {
		List<AHomeOperationVO> homeOperationVOList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				AHomeOperationVO ahomeOperationVO=new AHomeOperationVO();
				ahomeOperationVO.setHomePageId(rs.getString("HOMEPAGEID"));//病案首页ID
				ahomeOperationVO.setHospitalId(HOSPITAL_ID);//医院ID
				ahomeOperationVO.setOperationOrderNo(rs.getString("OPERATIONORDERNO"));//手术序号
				ahomeOperationVO.setOperationDate(rs.getString("OPERATIONDATE"));//手术日期
				ahomeOperationVO.setOperationCode(rs.getString("OPERATIONCODE"));//手术编码
				ahomeOperationVO.setOperationDoctorId(rs.getString("OPERATIONDOCTORID"));//手术医生
				ahomeOperationVO.setFirstAssistantId(rs.getString("FIRSTASSISTANTID"));//一助医生
				ahomeOperationVO.setSecondAssistantId(rs.getString("SECONDASSISTANTID"));//二助医生
				ahomeOperationVO.setCutLevel(rs.getString("CUTLEVEL"));//切口等级
				ahomeOperationVO.setHealingLevel(rs.getString("HEALINGLEVEL"));//愈合等级
				ahomeOperationVO.setOperationName(rs.getString("OPERATIONNAME"));//手术名称
				ahomeOperationVO.setOperationLevel(rs.getString("OPERATIONLEVEL"));//手术级别
				ahomeOperationVO.setAnaesthesiaName(rs.getString("ANAESTHESIANAME"));//麻醉方式
				ahomeOperationVO.setShamOperationName(rs.getString("SHAMOPERATIONNAME"));//拟手术名称
				homeOperationVOList.add(ahomeOperationVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return homeOperationVOList;
	}
	public List<AHomeDiagnoseVO> getHomePageDiagnose(String sql){
		List<AHomeDiagnoseVO> homeDiagnoseVOList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				AHomeDiagnoseVO aHomeDiagnoseVO=new AHomeDiagnoseVO();
				aHomeDiagnoseVO.setHomePageId(rs.getString("HOMEPAGEID"));//病案首页ID
				aHomeDiagnoseVO.setHospitalId(HOSPITAL_ID);//医院ID
				aHomeDiagnoseVO.setDiagnoseOrderNo(rs.getString("DIAGNOSEORDERNO"));//诊断序号
				aHomeDiagnoseVO.setDiagnoseName(rs.getString("DIAGNOSENAME"));//诊断名称
				aHomeDiagnoseVO.setDiagnoseType(rs.getString("DIAGNOSETYPE"));//诊断类别
				aHomeDiagnoseVO.setDiagnoseTypeShort(rs.getString("DIAGNOSETYPESHORT"));//诊断判别
				aHomeDiagnoseVO.setBehospitalType(rs.getString("BEHOSPITALTYPE"));//入院情况
				aHomeDiagnoseVO.setLeaveHospitalType(rs.getString("LEAVEHOSPITALTYPE"));//出院情况
				aHomeDiagnoseVO.setPathologyDiagnose(rs.getString("PATHOLOGYDIAGNOSE"));//病理号
				aHomeDiagnoseVO.setIcdCode(rs.getString("ICDCODE"));//诊断编码
				homeDiagnoseVOList.add(aHomeDiagnoseVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}
		return homeDiagnoseVOList;
	}

	/**
	 * 获取病人的住院号
	 * @return
	 */
	public List<String> getBeHospitalCode(String sql) {
		List<String> beHospitalCodeList=Lists.newLinkedList();
		try {
			TZDBConn dbconn=new TZDBConn();
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				beHospitalCodeList.add(rs.getString("BEHOSPITALCODE"));//病人住院ID
			}
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			close();
		}

		return beHospitalCodeList;
	}

}